@@ -683,7 +683,7 @@ class ImageOverlay : public GDKImageFilter, MagickImageLookup
 			int x = (int)( startx + ( endx - startx ) * position );
 			int y = (int)( starty + ( endy - starty ) * position );
 			int w = (int)( startwidth + ( endwidth - startwidth ) * position );
-			int h = (int)( startheight + ( endheight - startwidth ) * position );
+			int h = (int)( startheight + ( endheight - startheight ) * position );
 
 			convert.Clear();
 			sprintf( command, "%s -draw \"image %s %d,%d %d,%d '%s'\"", 
